==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/emr/kotlin/outputs/ClusterCoreInstanceFleetLaunchSpecifications.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.emr.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property onDemandSpecifications Configuration block for on demand instances launch specifications.
 * @property spotSpecifications Configuration block for spot instances launch specifications.
 */
public data class ClusterCoreInstanceFleetLaunchSpecifications(
    public val onDemandSpecifications:
    List<ClusterCoreInstanceFleetLaunchSpecificationsOnDemandSpecification>? = null,
    public val spotSpecifications:
    List<ClusterCoreInstanceFleetLaunchSpecificationsSpotSpecification>? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.emr.outputs.ClusterCoreInstanceFleetLaunchSpecifications):
            ClusterCoreInstanceFleetLaunchSpecifications = ClusterCoreInstanceFleetLaunchSpecifications(
            onDemandSpecifications = javaType.onDemandSpecifications().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.emr.kotlin.outputs.ClusterCoreInstanceFleetLaunchSpecificationsOnDemandSpecification.Companion.toKotlin(args0)
                })
            }),
            spotSpecifications = javaType.spotSpecifications().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.emr.kotlin.outputs.ClusterCoreInstanceFleetLaunchSpecificationsSpotSpecification.Companion.toKotlin(args0)
                })
            }),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/emr/kotlin/outputs/ClusterCoreInstanceFleetLaunchSpecifications.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.emr.kotlin.outputs

import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property onDemandSpecifications Configuration block for on demand instances launch specifications.
 * @property spotSpecifications Configuration block for spot instances launch specifications.
 */
public data class ClusterCoreInstanceFleetLaunchSpecifications(
    public val onDemandSpecifications: List<ClusterCoreInstanceFleetLaunchSpecificationsOnDemandSpecification>? = null,
    public val spotSpecifications: List<ClusterCoreInstanceFleetLaunchSpecificationsSpotSpecification>? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.emr.outputs.ClusterCoreInstanceFleetLaunchSpecifications): ClusterCoreInstanceFleetLaunchSpecifications = ClusterCoreInstanceFleetLaunchSpecifications(
            onDemandSpecifications = javaType.onDemandSpecifications().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.emr.kotlin.outputs.ClusterCoreInstanceFleetLaunchSpecificationsOnDemandSpecification.Companion.toKotlin(args0)
                })
            }),
            spotSpecifications = javaType.spotSpecifications().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.emr.kotlin.outputs.ClusterCoreInstanceFleetLaunchSpecificationsSpotSpecification.Companion.toKotlin(args0)
                })
            }),
        )
    }
}
